@@ -51,6 +51,10 @@ class Config(BaseModel):
     """B站视频编码"""
     parser_render_type: RenderType = RenderType.common
     """Renderer 类型"""
+    parser_custom_font: str | None = None
+    """自定义字体"""
+    parser_need_forward_contents: bool = True
+    """是否需要转发媒体内容"""
 
     @property
     def nickname(self) -> str:
@@ -127,6 +131,16 @@ class Config(BaseModel):
         """是否在解析结果中附加原始URL"""
         return self.parser_append_url
 
+    @property
+    def custom_font(self) -> Path | None:
+        """自定义字体"""
+        return (self.data_dir / self.parser_custom_font) if self.parser_custom_font else None
+
+    @property
+    def need_forward_contents(self) -> bool:
+        """是否需要转发媒体内容"""
+        return self.parser_need_forward_contents
+
 
 pconfig: Config = get_plugin_config(Config)
 """配置"""
