@@ -1,7 +1,6 @@
 # 导出所有 Parser 类
-from .acfun import AcfunParser as AcfunParser
+from .acfun import AcfunParser as AcfunParser  # noqa: I001
 from .base import BaseParser as BaseParser
-from .bilibili import BilibiliParser as BilibiliParser
 from .data import ParseResult as ParseResult
 from .douyin import DouyinParser as DouyinParser
 from .kuaishou import KuaiShouParser as KuaiShouParser
@@ -11,6 +10,7 @@ from .twitter import TwitterParser as TwitterParser
 from .weibo import WeiBoParser as WeiBoParser
 from .xiaohongshu import XiaoHongShuParser as XiaoHongShuParser
 from .youtube import YouTubeParser as YouTubeParser
+from .bilibili import BilibiliParser as BilibiliParser
 
 __all__ = [
     "ParseResult",
