@@ -61,21 +61,23 @@ class BilibiliParser(BaseParser):
         """
         # 从匹配对象中获取原始URL, 视频ID, 页码
         url, video_id, page_num = str(matched.group(0)), str(matched.group(1)), matched.group(2)
-
         # 处理短链
         if "b23.tv" in url or "bili2233.cn" in url:
             url = await self.get_redirect_url(url, self.headers)
 
         if not video_id:
-            if _matched := re.search(r"(BV[\dA-Za-z]{10})[^?]*?(?:\?[^#]*?p=(\d{1,3}))?", url):
-                video_id = _matched.group(1)
-                page_num = _matched.group(2)
-            elif _matched := re.search(r"av(\d{6,})[^?]*?(?:\?[^#]*?p=(\d{1,3}))?", url):
-                video_id = _matched.group(1)
-                page_num = _matched.group(2)
+            # https://www.bilibili.com/video/BV1584y167sD?a=20&p=40
+            if _matched := re.search(r"(?:(BV[\dA-Za-z]{10})|av(\d{6,}))", url):
+                video_id = _matched.group(1) or _matched.group(2)
             else:
                 return await self.parse_others(url)
 
+            # 匹配页码参数
+            if _matched := re.search(r"(?:&|\?)p=(\d{1,3})", url):
+                page_num = _matched.group(1)
+            else:
+                page_num = None
+
         avid, bvid = None, None
         page_num = int(page_num) if page_num and page_num.isdigit() else 1
 
@@ -161,6 +163,7 @@ class BilibiliParser(BaseParser):
     async def parse_others(self, url: str):
         """解析其他类型链接"""
         # 判断链接类型并解析
+        logger.debug(f"解析其他类型链接: {url}")
         # 1. 动态
         if "t.bilibili.com" in url:
             return await self.parse_dynamic(url)
@@ -199,47 +202,6 @@ class BilibiliParser(BaseParser):
 
         raise ParseException("不支持的 Bilibili 链接")
 
-    async def _init_credential(self) -> Credential | None:
-        """初始化 bilibili api"""
-
-        if not pconfig.bili_ck:
-            logger.warning("未配置 r_bili_ck, 无法使用哔哩哔哩 AI 总结, 可能无法解析 720p 以上画质视频")
-            return None
-
-        credential = Credential.from_cookies(ck2dict(pconfig.bili_ck))
-        if not await credential.check_valid() and self._cookies_file.exists():
-            logger.info(f"r_bili_ck 已过期, 尝试从 {self._cookies_file} 加载")
-            credential = Credential.from_cookies(json.loads(self._cookies_file.read_text()))
-        else:
-            logger.info(f"r_bili_ck 有效, 保存到 {self._cookies_file}")
-            self._cookies_file.write_text(json.dumps(credential.get_cookies()))
-
-        return credential
-
-    @property
-    async def credential(self) -> Credential | None:
-        """获取哔哩哔哩登录凭证"""
-
-        if self._credential is None:
-            self._credential = await self._init_credential()
-            if self._credential is None:
-                return None
-
-        if not await self._credential.check_valid():
-            logger.warning("哔哩哔哩 cookies 已过期, 请重新配置 r_bili_ck")
-            return self._credential
-
-        if await self._credential.check_refresh():
-            logger.info("哔哩哔哩 cookies 需要刷新")
-            if self._credential.has_ac_time_value() and self._credential.has_bili_jct():
-                await self._credential.refresh()
-                logger.info(f"哔哩哔哩 cookies 刷新成功, 保存到 {self._cookies_file}")
-                self._cookies_file.write_text(json.dumps(self._credential.get_cookies()))
-            else:
-                logger.warning("哔哩哔哩 cookies 刷新需要包含 SESSDATA, ac_time_value, bili_jct")
-
-        return self._credential
-
     async def parse_dynamic(self, url: str):
         """解析动态信息
 
@@ -286,8 +248,8 @@ class BilibiliParser(BaseParser):
         opus = Opus(opus_id, await self.credential)
         return await self._parse_opus(opus)
 
-    async def parse_read(self, read_id: int):
-        """解析专栏信息
+    async def parse_read_old(self, read_id: int):
+        """解析专栏信息, 已废弃
 
         Args:
             read_id (int): 专栏 id
@@ -307,39 +269,33 @@ class BilibiliParser(BaseParser):
             ParseResult: 解析结果
         """
 
-        from .opus import OpusImageNode, OpusItem, OpusTextNode
+        from .opus import ImageNode, OpusItem, TextNode
 
         opus_info = await bili_opus.get_info()
         if not isinstance(opus_info, dict):
             raise ParseException("获取图文动态信息失败")
         # 转换为结构体
         opus_data = msgspec.convert(opus_info, OpusItem)
-
+        logger.debug(f"opus_data: {opus_data}")
         author = self.create_author(*opus_data.name_avatar)
 
         # 按顺序处理图文内容（参考 parse_read 的逻辑）
         contents: list[MediaContent] = []
-        temp_text = None
+        current_text = ""
 
         for node in opus_data.gen_text_img():
-            match node:
-                case OpusImageNode():
-                    contents.append(self.create_graphics_content(node.url, temp_text))
-                    temp_text = None
-                case OpusTextNode():
-                    if temp_text is None:
-                        temp_text = ""
-                    temp_text += node.text
-
-        # 处理最后的文本内容
-        text_content = temp_text
+            if isinstance(node, ImageNode):
+                contents.append(self.create_graphics_content(node.url, current_text.strip(), node.alt))
+                current_text = ""
+            elif isinstance(node, TextNode):
+                current_text += node.text
 
         return self.result(
             title=opus_data.title,
             author=author,
             timestamp=opus_data.timestamp,
             contents=contents,
-            text=text_content,
+            text=current_text.strip(),
         )
 
     async def parse_live(self, room_id: int):
@@ -374,7 +330,7 @@ class BilibiliParser(BaseParser):
 
         return self.result(title=room_data.title, text=room_data.detail, contents=contents, author=author)
 
-    async def parse_read_old(self, read_id: int):
+    async def parse_read(self, read_id: int):
         """专栏解析
 
         Args:
@@ -393,23 +349,23 @@ class BilibiliParser(BaseParser):
         data = ar.json()
         article_info = msgspec.convert(data, ArticleInfo)
         logger.debug(f"article_info: {article_info}")
+
         contents: list[MediaContent] = []
-        temp_text = None
+        current_text = ""
         for child in article_info.gen_text_img():
-            match child:
-                case ImageNode():
-                    contents.append(self.create_graphics_content(child.url, temp_text, child.alt))
-                    temp_text = None
-                case TextNode():
-                    if temp_text is None:
-                        temp_text = ""
-                    temp_text += child.text
+            if isinstance(child, ImageNode):
+                contents.append(self.create_graphics_content(child.url, current_text.strip(), child.alt))
+                current_text = ""
+            elif isinstance(child, TextNode):
+                current_text += child.text
+
+        author = self.create_author(*article_info.author_info)
 
         return self.result(
-            title=article_info.meta.title,
-            timestamp=article_info.meta.publish_time,
-            text=temp_text,
-            author=self.create_author(article_info.meta.author.name, article_info.meta.author.face),
+            title=article_info.title,
+            timestamp=article_info.timestamp,
+            text=current_text.strip(),
+            author=author,
             contents=contents,
         )
 
@@ -499,3 +455,44 @@ class BilibiliParser(BaseParser):
             return video_stream.url, None
         logger.debug(f"音频流质量: {audio_stream.audio_quality.name}")
         return video_stream.url, audio_stream.url
+
+    async def _init_credential(self) -> Credential | None:
+        """初始化 bilibili api"""
+
+        if not pconfig.bili_ck:
+            logger.warning("未配置 parser_bili_ck, 无法使用哔哩哔哩 AI 总结, 可能无法解析 720p 以上画质视频")
+            return None
+
+        credential = Credential.from_cookies(ck2dict(pconfig.bili_ck))
+        if not await credential.check_valid() and self._cookies_file.exists():
+            logger.info(f"parser_bili_ck 已过期, 尝试从 {self._cookies_file} 加载")
+            credential = Credential.from_cookies(json.loads(self._cookies_file.read_text()))
+        else:
+            logger.info(f"parser_bili_ck 有效, 保存到 {self._cookies_file}")
+            self._cookies_file.write_text(json.dumps(credential.get_cookies()))
+
+        return credential
+
+    @property
+    async def credential(self) -> Credential | None:
+        """获取哔哩哔哩登录凭证"""
+
+        if self._credential is None:
+            self._credential = await self._init_credential()
+            if self._credential is None:
+                return None
+
+        if not await self._credential.check_valid():
+            logger.warning("哔哩哔哩 cookies 已过期, 请重新配置 parser_bili_ck")
+            return self._credential
+
+        if await self._credential.check_refresh():
+            logger.info("哔哩哔哩 cookies 需要刷新")
+            if self._credential.has_ac_time_value() and self._credential.has_bili_jct():
+                await self._credential.refresh()
+                logger.info(f"哔哩哔哩 cookies 刷新成功, 保存到 {self._cookies_file}")
+                self._cookies_file.write_text(json.dumps(self._credential.get_cookies()))
+            else:
+                logger.warning("哔哩哔哩 cookies 刷新需要包含 SESSDATA, ac_time_value, bili_jct")
+
+        return self._credential
