@@ -38,6 +38,5 @@ from nonebot import get_driver
 
 
 @get_driver().on_startup
-async def _():
-    # CommonRenderer.load_fonts()
-    CommonRenderer.load_custom_fonts()
+async def load_font():
+    _COMMON_RENDERER.load_resources()
