@@ -1,4 +1,5 @@
 from dataclasses import dataclass
+from functools import lru_cache
 from io import BytesIO
 from pathlib import Path
 from typing import ClassVar
@@ -10,14 +11,80 @@ from PIL import Image, ImageDraw, ImageFont
 from .base import ImageRenderer, ParseResult
 
 
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True, slots=True)
+class FontInfo:
+    """字体信息数据类"""
+
+    font: ImageFont.FreeTypeFont | ImageFont.ImageFont
+    line_height: int
+    cjk_width: int
+
+    def __hash__(self) -> int:
+        """实现哈希方法以支持 @lru_cache"""
+        return hash((id(self.font), self.line_height, self.cjk_width))
+
+    @lru_cache(maxsize=400)
+    def get_char_width(self, char: str) -> int:
+        """获取字符宽度，使用缓存优化"""
+        bbox = self.font.getbbox(char)
+        width = int(bbox[2] - bbox[0])
+        return width
+
+    def get_char_width_fast(self, char: str) -> int:
+        """快速获取单个字符宽度"""
+        if "\u4e00" <= char <= "\u9fff":
+            return self.cjk_width
+        else:
+            return self.get_char_width(char)
+
+    def get_text_width(self, text: str) -> int:
+        """计算文本宽度，使用预计算的字符宽度优化性能
+
+        Args:
+            text: 要计算宽度的文本
+
+        Returns:
+            文本宽度（像素）
+        """
+        if not text:
+            return 0
+
+        total_width = 0
+        for char in text:
+            total_width += self.get_char_width_fast(char)
+        return total_width
+
+
+@dataclass(eq=False, frozen=True, slots=True)
+class FontSet:
+    """字体集数据类"""
+
+    FONT_SIZES: ClassVar[dict[str, int]] = {"name": 28, "title": 30, "text": 24, "extra": 24, "indicator": 60}
+    """字体大小"""
+
+    name_font: FontInfo
+    title_font: FontInfo
+    text_font: FontInfo
+    extra_font: FontInfo
+    indicator_font: FontInfo
+
+    @classmethod
+    def new(cls, font_path: Path):
+        font_infos: dict[str, FontInfo] = {}
+        for name, size in cls.FONT_SIZES.items():
+            font = ImageFont.truetype(font_path, size)
+            font_infos[f"{name}_font"] = FontInfo(font=font, line_height=size + 4, cjk_width=size)
+        return FontSet(**font_infos)
+
+
+@dataclass(eq=False, frozen=True, slots=True)
 class SectionData:
     """基础部分数据类"""
 
     height: int
 
 
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True, slots=True)
 class HeaderSectionData(SectionData):
     """Header 部分数据"""
 
@@ -27,42 +94,42 @@ class HeaderSectionData(SectionData):
     text_height: int
 
 
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True, slots=True)
 class TitleSectionData(SectionData):
     """标题部分数据"""
 
     lines: list[str]
 
 
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True, slots=True)
 class CoverSectionData(SectionData):
     """封面部分数据"""
 
     cover_img: Image.Image
 
 
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True, slots=True)
 class TextSectionData(SectionData):
     """文本部分数据"""
 
     lines: list[str]
 
 
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True, slots=True)
 class ExtraSectionData(SectionData):
     """额外信息部分数据"""
 
     lines: list[str]
 
 
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True, slots=True)
 class RepostSectionData(SectionData):
     """转发部分数据"""
 
     scaled_image: Image.Image
 
 
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True, slots=True)
 class ImageGridSectionData(SectionData):
     """图片网格部分数据"""
 
@@ -73,18 +140,19 @@ class ImageGridSectionData(SectionData):
     remaining_count: int
 
 
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True, slots=True)
 class GraphicsSectionData(SectionData):
     """图文内容部分数据"""
 
     text_lines: list[str]
     image: Image.Image
+    alt_text: str | None = None
 
 
 class CommonRenderer(ImageRenderer):
     """统一的渲染器，将解析结果转换为消息"""
 
-    __slots__ = ("font_path", "fonts", "platform_logos", "video_button_image")
+    __slots__ = ("font_path", "fontset", "platform_logos", "video_button_image")
 
     # 卡片配置常量
     PADDING = 25
@@ -105,7 +173,6 @@ class CommonRenderer(ImageRenderer):
     """部分间距"""
     NAME_TIME_GAP = 5
     """名称和时间之间的间距"""
-
     AVATAR_UPSCALE_FACTOR = 2
     """头像圆形框超采样倍数"""
 
@@ -147,12 +214,6 @@ class CommonRenderer(ImageRenderer):
     REPOST_SCALE = 0.88
     """转发缩放比例"""
 
-    # 字体大小和行高
-    FONT_SIZES: ClassVar[dict[str, int]] = {"name": 28, "title": 30, "text": 24, "extra": 24}
-    """字体大小"""
-    LINE_HEIGHTS: ClassVar[dict[str, int]] = {"name": 32, "title": 36, "text": 28, "extra": 28}
-    """行高"""
-
     RESOURCES_DIR: ClassVar[Path] = Path(__file__).parent / "resources"
     """资源目录"""
     DEFAULT_FONT_PATH: ClassVar[Path] = RESOURCES_DIR / "HYSongYunLangHeiW-1.ttf"
@@ -176,9 +237,8 @@ class CommonRenderer(ImageRenderer):
         font_path = pconfig.custom_font
         if font_path is not None and font_path.exists():
             self.font_path = font_path
-        self.fonts: dict[str, ImageFont.FreeTypeFont | ImageFont.ImageFont] = {
-            name: ImageFont.truetype(self.font_path, size) for name, size in self.FONT_SIZES.items()
-        }
+        # 创建 FontSet 对象
+        self.fontset = FontSet.new(self.font_path)
         logger.success(f"加载字体「{self.font_path.name}」成功")
 
     def _load_video_button(self):
@@ -378,8 +438,8 @@ class CommonRenderer(ImageRenderer):
 
         # 2. 标题部分
         if result.title:
-            title_lines = self._wrap_text(result.title, content_width, self.fonts["title"])
-            title_height = len(title_lines) * self.LINE_HEIGHTS["title"]
+            title_lines = self._wrap_text(result.title, content_width, self.fontset.title_font)
+            title_height = len(title_lines) * self.fontset.title_font.line_height
             sections.append(TitleSectionData(height=title_height, lines=title_lines))
 
         # 3. 封面，图集，图文内容
@@ -398,14 +458,14 @@ class CommonRenderer(ImageRenderer):
 
         # 5. 文本内容
         if result.text:
-            text_lines = self._wrap_text(result.text, content_width, self.fonts["text"])
-            text_height = len(text_lines) * self.LINE_HEIGHTS["text"]
+            text_lines = self._wrap_text(result.text, content_width, self.fontset.text_font)
+            text_height = len(text_lines) * self.fontset.text_font.line_height
             sections.append(TextSectionData(height=text_height, lines=text_lines))
 
         # 6. 额外信息
         if result.extra_info:
-            extra_lines = self._wrap_text(result.extra_info, content_width, self.fonts["extra"])
-            extra_height = len(extra_lines) * self.LINE_HEIGHTS["extra"]
+            extra_lines = self._wrap_text(result.extra_info, content_width, self.fontset.extra_font)
+            extra_height = len(extra_lines) * self.fontset.extra_font.line_height
             sections.append(ExtraSectionData(height=extra_height, lines=extra_lines))
 
         # 6. 转发内容
@@ -435,15 +495,20 @@ class CommonRenderer(ImageRenderer):
             # 处理文本内容
             text_lines = []
             if graphics_content.text:
-                text_lines = self._wrap_text(graphics_content.text, content_width, self.fonts["text"])
+                text_lines = self._wrap_text(graphics_content.text, content_width, self.fontset.text_font)
 
-            # 计算总高度：文本高度 + 图片高度 + 间距
-            text_height = len(text_lines) * self.LINE_HEIGHTS["text"] if text_lines else 0
-            total_height = text_height + image.height
+            # 计算总高度：文本高度 + 图片高度 + alt文本高度 + 间距
+            text_height = len(text_lines) * self.fontset.text_font.line_height if text_lines else 0
+            alt_height = self.fontset.extra_font.line_height if graphics_content.alt else 0
+            total_height = text_height + image.height + alt_height
             if text_lines:
                 total_height += self.SECTION_SPACING  # 文本和图片之间的间距
+            if graphics_content.alt:
+                total_height += self.SECTION_SPACING  # 图片和alt文本之间的间距
 
-            return GraphicsSectionData(height=total_height, text_lines=text_lines, image=image)
+            return GraphicsSectionData(
+                height=total_height, text_lines=text_lines, image=image, alt_text=graphics_content.alt
+            )
         except Exception:
             return None
 
@@ -459,16 +524,16 @@ class CommonRenderer(ImageRenderer):
         text_area_width = content_width - (self.AVATAR_SIZE + self.AVATAR_TEXT_GAP)
 
         # 发布者名称
-        name_lines = self._wrap_text(result.author.name, text_area_width, self.fonts["name"])
+        name_lines = self._wrap_text(result.author.name, text_area_width, self.fontset.name_font)
 
         # 时间
         time_text = result.formartted_datetime
-        time_lines = self._wrap_text(time_text, text_area_width, self.fonts["extra"]) if time_text else []
+        time_lines = self._wrap_text(time_text, text_area_width, self.fontset.extra_font) if time_text else []
 
         # 计算 header 高度（取头像和文字中较大者）
-        text_height = len(name_lines) * self.LINE_HEIGHTS["name"]
+        text_height = len(name_lines) * self.fontset.name_font.line_height
         if time_lines:
-            text_height += self.NAME_TIME_GAP + len(time_lines) * self.LINE_HEIGHTS["extra"]
+            text_height += self.NAME_TIME_GAP + len(time_lines) * self.fontset.extra_font.line_height
         header_height = max(self.AVATAR_SIZE, text_height)
 
         return HeaderSectionData(
@@ -635,15 +700,15 @@ class CommonRenderer(ImageRenderer):
                 case HeaderSectionData() as header:
                     y_pos = self._draw_header(image, draw, header, y_pos, result, not_repost)
                 case TitleSectionData() as title:
-                    y_pos = self._draw_title(draw, title.lines, y_pos, self.fonts["title"])
+                    y_pos = self._draw_title(draw, title.lines, y_pos, self.fontset.title_font.font)
                 case CoverSectionData() as cover:
                     y_pos = self._draw_cover(image, cover.cover_img, y_pos, card_width)
                 case TextSectionData() as text:
-                    y_pos = self._draw_text(draw, text.lines, y_pos, self.fonts["text"])
+                    y_pos = self._draw_text(draw, text.lines, y_pos, self.fontset.text_font.font)
                 case GraphicsSectionData() as graphics:
                     y_pos = self._draw_graphics(image, draw, graphics, y_pos, card_width)
                 case ExtraSectionData() as extra:
-                    y_pos = self._draw_extra(draw, extra.lines, y_pos, self.fonts["extra"])
+                    y_pos = self._draw_extra(draw, extra.lines, y_pos, self.fontset.extra_font.font)
                 case RepostSectionData() as repost:
                     y_pos = self._draw_repost(image, draw, repost, y_pos, card_width)
                 case ImageGridSectionData() as image_grid:
@@ -731,15 +796,15 @@ class CommonRenderer(ImageRenderer):
 
         # 发布者名称（蓝色）
         for line in section.name_lines:
-            draw.text((text_x, text_y), line, fill=self.HEADER_COLOR, font=self.fonts["name"])
-            text_y += self.LINE_HEIGHTS["name"]
+            draw.text((text_x, text_y), line, fill=self.HEADER_COLOR, font=self.fontset.name_font.font)
+            text_y += self.fontset.name_font.line_height
 
         # 时间（灰色）
         if section.time_lines:
             text_y += self.NAME_TIME_GAP
             for line in section.time_lines:
-                draw.text((text_x, text_y), line, fill=self.EXTRA_COLOR, font=self.fonts["extra"])
-                text_y += self.LINE_HEIGHTS["extra"]
+                draw.text((text_x, text_y), line, fill=self.EXTRA_COLOR, font=self.fontset.extra_font.font)
+                text_y += self.fontset.extra_font.line_height
 
         # 在右侧绘制平台 logo（仅在非转发内容时绘制）
         if not_repost:
@@ -758,7 +823,7 @@ class CommonRenderer(ImageRenderer):
         """绘制标题"""
         for line in lines:
             draw.text((self.PADDING, y_pos), line, fill=self.TEXT_COLOR, font=font)
-            y_pos += self.LINE_HEIGHTS["title"]
+            y_pos += self.fontset.title_font.line_height
         return y_pos + self.SECTION_SPACING
 
     def _draw_cover(self, image: Image.Image, cover_img: Image.Image, y_pos: int, card_width: int) -> int:
@@ -779,7 +844,7 @@ class CommonRenderer(ImageRenderer):
         """绘制文本内容"""
         for line in lines:
             draw.text((self.PADDING, y_pos), line, fill=self.TEXT_COLOR, font=font)
-            y_pos += self.LINE_HEIGHTS["text"]
+            y_pos += self.fontset.text_font.line_height
         return y_pos + self.SECTION_SPACING
 
     def _draw_graphics(
@@ -789,21 +854,33 @@ class CommonRenderer(ImageRenderer):
         # 绘制文本内容（如果有）
         if section.text_lines:
             for line in section.text_lines:
-                draw.text((self.PADDING, y_pos), line, fill=self.TEXT_COLOR, font=self.fonts["text"])
-                y_pos += self.LINE_HEIGHTS["text"]
+                draw.text((self.PADDING, y_pos), line, fill=self.TEXT_COLOR, font=self.fontset.text_font.font)
+                y_pos += self.fontset.text_font.line_height
             y_pos += self.SECTION_SPACING  # 文本和图片之间的间距
 
-        # 绘制图片
-        x_pos = self.PADDING
+        # 绘制图片（居中）
+        content_width = card_width - 2 * self.PADDING
+        x_pos = self.PADDING + (content_width - section.image.width) // 2
         image.paste(section.image, (x_pos, y_pos))
+        y_pos += section.image.height
 
-        return y_pos + section.image.height + self.SECTION_SPACING
+        # 绘制 alt 文本（如果有，居中显示）
+        if section.alt_text:
+            y_pos += self.SECTION_SPACING  # 图片和alt文本之间的间距
+            # 计算文本居中位置
+            extra_font_info = self.fontset.extra_font
+            text_width = extra_font_info.get_text_width(section.alt_text)
+            text_x = self.PADDING + (content_width - text_width) // 2
+            draw.text((text_x, y_pos), section.alt_text, fill=self.EXTRA_COLOR, font=extra_font_info.font)
+            y_pos += extra_font_info.line_height
+
+        return y_pos + self.SECTION_SPACING
 
     def _draw_extra(self, draw: ImageDraw.ImageDraw, lines: list[str], y_pos: int, font) -> int:
         """绘制额外信息"""
         for line in lines:
             draw.text((self.PADDING, y_pos), line, fill=self.EXTRA_COLOR, font=font)
-            y_pos += self.LINE_HEIGHTS["extra"]
+            y_pos += self.fontset.extra_font.line_height
         return y_pos
 
     def _draw_repost(
@@ -917,19 +994,14 @@ class CommonRenderer(ImageRenderer):
 
         # 绘制+N文字
         text = f"+{count}"
-        # 使用更大的字体
-        font_size = min(img_width, img_height) // 4
-        font = ImageFont.truetype(self.font_path, font_size)
-
+        font_info = self.fontset.indicator_font
         # 计算文字位置（居中）
-        bbox = font.getbbox(text)
-        text_width = bbox[2] - bbox[0]
-        text_height = bbox[3] - bbox[1]
+        text_width = font_info.get_text_width(text)
         text_x = img_x + (img_width - text_width) // 2
-        text_y = img_y + (img_height - text_height) // 2
+        text_y = img_y + (img_height - font_info.line_height) // 2
 
-        # 绘制白色文字
-        draw.text((text_x, text_y), text, fill=(255, 255, 255, 255), font=font)
+        # 绘制50%透明白色文字
+        draw.text((text_x, text_y), text, fill=(255, 255, 255), font=font_info.font)
 
     def _draw_rounded_rectangle(
         self, image: Image.Image, bbox: tuple[int, int, int, int], fill_color: tuple[int, int, int], radius: int = 8
@@ -971,13 +1043,13 @@ class CommonRenderer(ImageRenderer):
         draw.arc((x1, y2 - 2 * radius, x1 + 2 * radius, y2), 90, 180, fill=border_color, width=width)
         draw.arc((x2 - 2 * radius, y2 - 2 * radius, x2, y2), 0, 90, fill=border_color, width=width)
 
-    def _wrap_text(self, text: str, max_width: int, font: ImageFont.FreeTypeFont | ImageFont.ImageFont) -> list[str]:
-        """文本自动换行
+    def _wrap_text(self, text: str, max_width: int, font_info: FontInfo) -> list[str]:
+        """优化的文本自动换行算法，考虑中英文字符宽度相同
 
         Args:
             text: 要处理的文本
             max_width: 最大宽度（像素）
-            font: 字体
+            font_info: 字体信息对象
 
         Returns:
             换行后的文本列表
@@ -988,29 +1060,56 @@ class CommonRenderer(ImageRenderer):
         lines = []
         paragraphs = text.split("\n")
 
+        def is_punctuation(char: str) -> bool:
+            """判断是否为不能为行首的标点符号"""
+            # 中文标点符号
+            chinese_punctuation = "，。！？；：、）】》〉」』〕〗〙〛…—·"
+            # 英文标点符号
+            english_punctuation = ",.;:!?)]}"
+
+            return char in chinese_punctuation or char in english_punctuation
+
         for paragraph in paragraphs:
             if not paragraph:
                 lines.append("")
                 continue
 
             current_line = ""
-            for char in paragraph:
-                test_line = current_line + char
-                # 使用 getbbox 计算文本宽度
-                bbox = font.getbbox(test_line)
-                width = bbox[2] - bbox[0]
+            current_line_width = 0
+            remaining_text = paragraph
 
-                if width <= max_width:
-                    current_line = test_line
+            while remaining_text:
+                next_char = remaining_text[0]
+                char_width = font_info.get_char_width_fast(next_char)
+
+                # 如果当前行为空，直接添加字符
+                if not current_line:
+                    current_line = next_char
+                    current_line_width = char_width
+                    remaining_text = remaining_text[1:]
+                    continue
+
+                # 如果是标点符号，直接添加到当前行（标点符号不应该单独成行）
+                if is_punctuation(next_char):
+                    current_line += next_char
+                    current_line_width += char_width
+                    remaining_text = remaining_text[1:]
+                    continue
+
+                # 测试添加下一个字符后的宽度
+                test_width = current_line_width + char_width
+
+                if test_width <= max_width:
+                    # 宽度合适，继续添加
+                    current_line += next_char
+                    current_line_width = test_width
+                    remaining_text = remaining_text[1:]
                 else:
-                    # 如果当前行不为空，保存并开始新行
-                    if current_line:
-                        lines.append(current_line)
-                        current_line = char
-                    else:
-                        # 单个字符就超宽，强制添加
-                        lines.append(char)
-                        current_line = ""
+                    # 宽度超限，需要断行
+                    lines.append(current_line)
+                    current_line = next_char
+                    current_line_width = char_width
+                    remaining_text = remaining_text[1:]
 
             # 保存最后一行
             if current_line:
